import numpy as np
from netCDF4 import Dataset
import sys, os
from importlib import reload
import xarray as xr

import pyicon as pyic
reload(pyic)

ts = pyic.timing([0], 'start')

# path + file with the target coordinates
pathIn        = '/hpc/uwork/icon-sml/ICON-CLM/data/rcm/EUR11/'
proj_name     = 'europe011_rotated'
filename      = proj_name+'_grid.nc'

# information about the icosahedral grid and output path for the ckdtree:
tgname        = 'icon-clm'
gname         = 'icon-clm_tgrid'
path_tgrid    = f'/hpc/uwork/icon-sml/pyICON/grids/icon-clm/'
fname_tgrid   = f'{gname}.nc'
path_ckdtree  = f'/hpc/uwork/vmaurer/{tgname}/ckdtree/'
path_rgrid    = path_ckdtree + 'rectgrids/' 
path_sections = path_ckdtree + 'sections/' 

all_grids = [
  'regional_0.25_europe011_rotated',
  #'regional_0.44_europe011',
  #'regional_0.25_europe011'
            ]

all_secs = []

#------------------------- Functions ---------------------------

def get_rotated_coord(pathIn, filename):
  # this routine is specifically adapted for a grid file with a rotated pole
  # generated by a COSMO routine

  print('')
  print('... read target lon and lat from file ...')

  # input file
  dataIn = f'{pathIn}{filename}'

  # load input as xarray.Dataset
  dsIn = xr.open_dataset(dataIn)

  # close xarray.Datasets
  dsIn.close()

  return dsIn.lon.values, dsIn.lat.values, dsIn.rlon.values, dsIn.rlat.values, \
         dsIn.rotated_pole.grid_north_pole_longitude, dsIn.rotated_pole.grid_north_pole_latitude


#------------------------- Main ---------------------------
gnames = [gname]

if not os.path.exists(path_rgrid): 
  os.makedirs(path_rgrid)
if not os.path.exists(path_sections): 
  os.makedirs(path_sections)
fpath = f'{path_ckdtree}/../{tgname}_tgrid.nc'
if not os.path.exists(fpath):
  os.symlink(path_tgrid+fname_tgrid, fpath)

for gname in gnames:
  ts = pyic.timing(ts, gname)
  print(gname)

  # --- grids
  sname = 'regional_0.44_europe011'
  if sname in all_grids:
    pyic.ckdtree_hgrid(lon_reg=[-19.,40.], lat_reg=[36.,70.], res=0.44,
                      fname_tgrid  = fname_tgrid,
                      path_tgrid   = path_tgrid,
                      path_ckdtree = path_rgrid,
                      sname = sname,
                      gname = gname,
                      tgname = tgname,
                      save_as_nc=False,
                      )

  sname = 'regional_0.25_europe011'
  if sname in all_grids:
    pyic.ckdtree_hgrid(lon_reg=[-19.,40.], lat_reg=[36.,69.], res=0.25,
                      fname_tgrid  = fname_tgrid,
                      path_tgrid   = path_tgrid,
                      path_ckdtree = path_rgrid,
                      sname = sname,
                      gname = gname,
                      tgname = tgname,
                      save_as_nc=False,
                      )

  lon_proj, lat_proj, rlon, rlat, pol_lon, pol_lat = get_rotated_coord(pathIn, filename)

  sname = 'regional_0.25_europe011_rotated'
  if sname in all_grids:
    pyic.ckdtree_hgrid_rotated(Lon=lon_proj, Lat=lat_proj,
                      rlon=rlon, rlat=rlat,
                      pol_lon=pol_lon, pol_lat=pol_lat,
                      proj_name=proj_name,
                      fname_tgrid  = fname_tgrid,
                      path_tgrid   = path_tgrid,
                      path_ckdtree = path_rgrid,
                      sname = sname,
                      gname = gname,
                      tgname = tgname,
                      save_as_nc=False,
                      )


print('make_ckdtree.py: All done!')
ts = pyic.timing(ts, 'All done!')
